### MMGen version 0.9.6 Release Notes

#### New features:

  - Key/address generation support for ETH, ETC, ZEC, XMR and 144 Bitcoin-derived altcoins
  - Zcash z-address support (Linux only)
  - Monero wallet generation utility (Linux only): `mmgen-tool keyaddrlist2monerowallet`
  - 32-byte hexadecimal password generation with `mmgen-passgen --hex`

  Altcoin support is EXPERIMENTAL. Use at your own risk
